@@ -8,7 +8,7 @@
 
 #include <asm/types.h>		/* For __uXX types */
 
-#define IP_VS_VERSION_CODE	0x010100
+#define IP_VS_VERSION_CODE	0x010101
 #define NVERSION(version)			\
 	(version >> 16) & 0xFF,			\
 	(version >> 8) & 0xFF,			\
@@ -394,6 +394,17 @@ union ip_vs_tphdr {
 };
 
 
+/*
+ *	Slow timer for IPVS connections
+ */
+struct sltimer_list {
+	struct list_head	list;
+	unsigned long		expires;
+	unsigned long		data;
+	void (*function)(unsigned long);
+};
+
+
 /*
  *	Delta sequence info structure
  *	Each ip_vs_conn has 2 (output AND input seq. changes).
@@ -517,7 +528,7 @@ struct ip_vs_conn {
 
 	/* counter and timer */
 	atomic_t		refcnt;		/* reference count */
-	struct timer_list	timer;		/* Expiration timer */
+	struct sltimer_list	timer;		/* Expiration timer */
 	volatile unsigned long	timeout;	/* timeout */
 
 	/* Flags and state transition */
@@ -741,16 +752,6 @@ enum {
 	IP_VS_DIR_LAST,
 };
 
-/*
- *      Slow timer functions for IPVS
- *      (from ip_vs_timer.c)
- */
-extern void add_sltimer(struct timer_list * timer);
-extern int  del_sltimer(struct timer_list * timer);
-extern void mod_sltimer(struct timer_list *timer, unsigned long expires);
-extern void ip_vs_sltimer_init(void);
-extern void ip_vs_sltimer_cleanup(void);
-
 extern struct ip_vs_conn *ip_vs_conn_in_get
 (int protocol, __u32 s_addr, __u16 s_port, __u32 d_addr, __u16 d_port);
 extern struct ip_vs_conn *ip_vs_conn_out_get
@@ -927,6 +928,26 @@ extern void ip_vs_kill_estimator(struct ip_vs_stats *stats);
 extern void ip_vs_zero_estimator(struct ip_vs_stats *stats);
 
 
+/*
+ *      Slow timer functions for IPVS
+ *      (from ip_vs_timer.c)
+ */
+extern void add_sltimer(struct sltimer_list *timer);
+extern int  del_sltimer(struct sltimer_list *timer);
+extern void mod_sltimer(struct sltimer_list *timer, unsigned long expires);
+extern void ip_vs_sltimer_init(void);
+extern void ip_vs_sltimer_cleanup(void);
+static inline void init_sltimer(struct sltimer_list *timer)
+{
+	timer->list.next = timer->list.prev = NULL;
+}
+
+static inline int sltimer_pending(const struct sltimer_list *timer)
+{
+	return timer->list.next != NULL;
+}
+
+
 /*
  *	Various IPVS packet transmitters (from ip_vs_xmit.c)
  */
