@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_ctl.c,v 1.31 2002/09/15 08:14:08 wensong Exp $
+ * Version:     $Id: ip_vs_ctl.c,v 1.32 2002/11/30 01:50:35 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -1001,10 +1001,10 @@ ip_vs_add_service(struct ip_vs_service_user *u, struct ip_vs_service **svc_p)
 		IP_VS_INFO("Scheduler module ip_vs_%s.o not found\n",
 			   u->sched_name);
 		ret = -ENOENT;
-		goto out_err;
+		goto out_mod_dec;
 	}
 
-	svc = (struct ip_vs_service*)
+	svc = (struct ip_vs_service *)
 		kmalloc(sizeof(struct ip_vs_service), GFP_ATOMIC);
 	if (svc == NULL) {
 		IP_VS_DBG(1, "ip_vs_add_service: kmalloc failed.\n");
@@ -1053,17 +1053,18 @@ ip_vs_add_service(struct ip_vs_service_user *u, struct ip_vs_service **svc_p)
 	return 0;
 
   out_err:
-	if (svc->scheduler)
-		ip_vs_unbind_scheduler(svc);
-	if (svc->inc) {
-		local_bh_disable();
-		ip_vs_app_inc_put(svc->inc);
-		local_bh_enable();
-	}
-	if (sched)
-		ip_vs_scheduler_put(sched);
-	if (svc)
+	if (svc != NULL) {
+		if (svc->scheduler)
+			ip_vs_unbind_scheduler(svc);
+		if (svc->inc) {
+			local_bh_disable();
+			ip_vs_app_inc_put(svc->inc);
+			local_bh_enable();
+		}
 		kfree(svc);
+	}
+	ip_vs_scheduler_put(sched);
+  out_mod_dec:
 	MOD_DEC_USE_COUNT;
 	return ret;
 }
@@ -1989,8 +1990,10 @@ do_ip_vs_get_ctl(struct sock *sk, int cmd, void *user, int *len)
 
 		sprintf(buf, "IP Virtual Server version %d.%d.%d (size=%d)",
 			NVERSION(IP_VS_VERSION_CODE), IP_VS_CONN_TAB_SIZE);
-		if (copy_to_user(user, buf, strlen(buf)+1) != 0)
-			return -EFAULT;
+		if (copy_to_user(user, buf, strlen(buf)+1) != 0) {
+			ret = -EFAULT;
+			goto out;
+		}
 		*len = strlen(buf)+1;
 	}
 	break;
@@ -2002,7 +2005,7 @@ do_ip_vs_get_ctl(struct sock *sk, int cmd, void *user, int *len)
 		info.size = IP_VS_CONN_TAB_SIZE;
 		info.num_services = ip_vs_num_services;
 		if (copy_to_user(user, &info, sizeof(info)) != 0)
-			return -EFAULT;
+			ret = -EFAULT;
 	}
 	break;
 
@@ -2016,7 +2019,8 @@ do_ip_vs_get_ctl(struct sock *sk, int cmd, void *user, int *len)
 			sizeof(struct ip_vs_service_entry) * get->num_services;
 		if (*len != size) {
 			IP_VS_ERR("length: %u != %u\n", *len, size);
-			return -EINVAL;
+			ret = -EINVAL;
+			goto out;
 		}
 		ret = __ip_vs_get_service_entries(get, user);
 	}
@@ -2053,7 +2057,8 @@ do_ip_vs_get_ctl(struct sock *sk, int cmd, void *user, int *len)
 			sizeof(struct ip_vs_dest_entry) * get->num_dests;
 		if (*len != size) {
 			IP_VS_ERR("length: %u != %u\n", *len, size);
-			return -EINVAL;
+			ret = -EINVAL;
+			goto out;
 		}
 		ret = __ip_vs_get_dest_entries(get, user);
 	}
@@ -2084,6 +2089,7 @@ do_ip_vs_get_ctl(struct sock *sk, int cmd, void *user, int *len)
 		ret = -EINVAL;
 	}
 
+  out:
 	up(&__ip_vs_mutex);
 	return ret;
 }
