@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_sync.c,v 1.9 2002/09/15 08:14:08 wensong Exp $
+ * Version:     $Id: ip_vs_sync.c,v 1.10 2002/11/30 01:50:35 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -690,10 +690,10 @@ static int sync_thread(void *startup)
 		sprintf(current->comm, "ipvs syncbackup");
 	else IP_VS_BUG();
 
-	spin_lock_irq(&current->sigmask_lock);
+	spin_lock_irq(&current->sig->siglock);
 	siginitsetinv(&current->blocked, 0);
 	recalc_sigpending();
-	spin_unlock_irq(&current->sigmask_lock);
+	spin_unlock_irq(&current->sig->siglock);
 
 	/* set up multicast address */
 	mcast_addr.sin_family = AF_INET;
