@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_timer.c,v 1.8.2.2 2003/05/20 17:05:02 wensong Exp $
+ * Version:     $Id: ip_vs_timer.c,v 1.9 2002/11/30 01:50:35 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Julian Anastasov <ja@ssi.bg>
@@ -59,7 +59,7 @@ static struct sltimer_vec * const sltvecs[] = {
 
 #define NOOF_SLTVECS (sizeof(sltvecs) / sizeof(sltvecs[0]))
 
-static void init_sltimervecs (void)
+static void init_sltimervecs(void)
 {
 	int i;
 
@@ -73,7 +73,7 @@ static void init_sltimervecs (void)
 
 static unsigned long sltimer_jiffies = 0;
 
-static inline void internal_add_sltimer(struct timer_list *timer)
+static inline void internal_add_sltimer(struct sltimer_list *timer)
 {
 	/*
 	 * must hold the sltimer lock when calling this
@@ -110,7 +110,7 @@ static inline void internal_add_sltimer(struct timer_list *timer)
 
 static spinlock_t __ip_vs_sltimerlist_lock = SPIN_LOCK_UNLOCKED;
 
-void add_sltimer(struct timer_list *timer)
+void add_sltimer(struct sltimer_list *timer)
 {
 	spin_lock(&__ip_vs_sltimerlist_lock);
 	if (timer->list.next)
@@ -126,15 +126,15 @@ void add_sltimer(struct timer_list *timer)
 	goto out;
 }
 
-static inline int detach_sltimer(struct timer_list *timer)
+static inline int detach_sltimer(struct sltimer_list *timer)
 {
-	if (!timer_pending(timer))
+	if (!sltimer_pending(timer))
 		return 0;
 	list_del(&timer->list);
 	return 1;
 }
 
-void mod_sltimer(struct timer_list *timer, unsigned long expires)
+void mod_sltimer(struct sltimer_list *timer, unsigned long expires)
 {
 	int ret;
 
@@ -145,7 +145,7 @@ void mod_sltimer(struct timer_list *timer, unsigned long expires)
 	spin_unlock(&__ip_vs_sltimerlist_lock);
 }
 
-int del_sltimer(struct timer_list * timer)
+int del_sltimer(struct sltimer_list * timer)
 {
 	int ret;
 
@@ -172,9 +172,9 @@ static inline void cascade_sltimers(struct sltimer_vec *tv)
 	 * detach them individually, just clear the list afterwards.
 	 */
 	while (curr != head) {
-		struct timer_list *tmp;
+		struct sltimer_list *tmp;
 
-		tmp = list_entry(curr, struct timer_list, list);
+		tmp = list_entry(curr, struct sltimer_list, list);
 		next = curr->next;
 		list_del(curr); // not needed
 		internal_add_sltimer(tmp);
@@ -199,11 +199,11 @@ static inline void run_sltimer_list(void)
 		head = sltv1.vec + sltv1.index;
 		curr = head->next;
 		if (curr != head) {
-			struct timer_list *timer;
+			struct sltimer_list *timer;
 			void (*fn)(unsigned long);
 			unsigned long data;
 
-			timer = list_entry(curr, struct timer_list, list);
+			timer = list_entry(curr, struct sltimer_list, list);
 			fn = timer->function;
 			data= timer->data;
 
