@@ -1,7 +1,7 @@
 /*
  * IPVS:        Weighted Least-Connection Scheduling module
  *
- * Version:     $Id: ip_vs_wlc.c,v 1.10 2002/03/25 12:44:35 wensong Exp $
+ * Version:     $Id: ip_vs_wlc.c,v 1.11 2002/09/15 08:14:08 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -80,13 +80,14 @@ ip_vs_wlc_schedule(struct ip_vs_service *svc, struct iphdr *iph)
 	 * if every weight is larger than zero.
 	 *
 	 * The server with weight=0 is quiesced and will not receive any
-	 * new connection.
+	 * new connections.
 	 */
 
 	l = &svc->destinations;
 	for (e=l->next; e!=l; e=e->next) {
 		least = list_entry(e, struct ip_vs_dest, n_list);
-		if (atomic_read(&least->weight) > 0) {
+		if (!(least->flags & IP_VS_DEST_F_OVERLOAD) &&
+		    atomic_read(&least->weight) > 0) {
 			loh = atomic_read(&least->activeconns) * 50
 				+ atomic_read(&least->inactconns);
 			goto nextstage;
@@ -100,6 +101,9 @@ ip_vs_wlc_schedule(struct ip_vs_service *svc, struct iphdr *iph)
   nextstage:
 	for (e=e->next; e!=l; e=e->next) {
 		dest = list_entry(e, struct ip_vs_dest, n_list);
+
+		if (dest->flags & IP_VS_DEST_F_OVERLOAD)
+			continue;
 		doh = atomic_read(&dest->activeconns) * 50
 			+ atomic_read(&dest->inactconns);
 		if (loh * atomic_read(&dest->weight) >
@@ -122,14 +126,13 @@ ip_vs_wlc_schedule(struct ip_vs_service *svc, struct iphdr *iph)
 
 static struct ip_vs_scheduler ip_vs_wlc_scheduler =
 {
-	{0},			/* n_list */
-	"wlc",			/* name */
-	ATOMIC_INIT(0),         /* refcnt */
-	THIS_MODULE,		/* this module */
-	ip_vs_wlc_init_svc,	/* service initializer */
-	ip_vs_wlc_done_svc,	/* service done */
-	ip_vs_wlc_update_svc,	/* service updater */
-	ip_vs_wlc_schedule,	/* select a server from the destination list */
+	.name =			"wlc",
+	.refcnt =		ATOMIC_INIT(0),
+	.module =		THIS_MODULE,
+	.init_service =		ip_vs_wlc_init_svc,
+	.done_service =		ip_vs_wlc_done_svc,
+	.update_service =	ip_vs_wlc_update_svc,
+	.schedule =		ip_vs_wlc_schedule,
 };
 
 
