@@ -1,7 +1,7 @@
 /*
  * libipvs.h:	header file for the library ipvs
  *
- * Version:	$Id: libipvs.h,v 1.4 2002/09/15 08:14:15 wensong Exp $
+ * Version:	$Id: libipvs.h,v 1.5 2002/11/30 01:50:38 wensong Exp $
  *
  * Authors:	Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -82,6 +82,9 @@ extern int ipvs_update_dest(ipvs_service_t *svc, ipvs_dest_t *dest);
 /* remove a destination server from a service */
 extern int ipvs_del_dest(ipvs_service_t *svc, ipvs_dest_t *dest);
 
+/* set timeout */
+extern int ipvs_set_timeout(ipvs_timeout_t *to);
+
 /* start the connection synchronizaiton daemon */
 extern int ipvs_start_daemon(ipvs_daemon_t *dm);
 
@@ -92,9 +95,25 @@ extern int ipvs_stop_daemon(void);
 /* get all the ipvs services */
 extern struct ip_vs_get_services *ipvs_get_services(void);
 
+/* sort the service entries */
+typedef int (*ipvs_service_cmp_t)(ipvs_service_entry_t *,
+				  ipvs_service_entry_t *);
+extern int ipvs_cmp_services(ipvs_service_entry_t *s1,
+			     ipvs_service_entry_t *s2);
+extern void ipvs_sort_services(struct ip_vs_get_services *s,
+			       ipvs_service_cmp_t f);
+
 /* get the destination array of the specified service */
 extern struct ip_vs_get_dests *ipvs_get_dests(ipvs_service_entry_t *svc);
 
+/* sort the destination entries */
+typedef int (*ipvs_dest_cmp_t)(ipvs_dest_entry_t *,
+			       ipvs_dest_entry_t *);
+extern int ipvs_cmp_dests(ipvs_dest_entry_t *d1,
+			  ipvs_dest_entry_t *d2);
+extern void ipvs_sort_dests(struct ip_vs_get_dests *d,
+			    ipvs_dest_cmp_t f);
+
 /* get an ipvs service entry */
 extern ipvs_service_entry_t *
 ipvs_get_service(__u32 fwmark, __u16 protocol, __u32 addr, __u16 port);
